==> jc-1.4.0.tar.gz: polyglot/types/NoClassException.h <==
// public class polyglot.types.NoClassException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 7e014a610596faf9 polyglot_types_NoClassException
// @dep_class 45f755f5298b5b39 polyglot_types_SemanticException

// header file dependencies
// @dep_header polyglot_types_SemanticException

#include "polyglot/types/SemanticException.h"

#ifndef _JC_polyglot_types_NoClassException_H_
#define _JC_polyglot_types_NoClassException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_ClassType$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_types_NoClassException$sub_refs	_jc_polyglot_types_NoClassException$sub_refs;
typedef struct _jc_polyglot_types_NoClassException$sub_nonrefs	_jc_polyglot_types_NoClassException$sub_nonrefs;
typedef struct _jc_polyglot_types_NoClassException$refs	_jc_polyglot_types_NoClassException$refs;
typedef struct _jc_polyglot_types_NoClassException$nonrefs	_jc_polyglot_types_NoClassException$nonrefs;
typedef struct _jc_polyglot_types_NoClassException$object	_jc_polyglot_types_NoClassException$object;

typedef const struct _jc_polyglot_types_NoClassException$vmethods	_jc_polyglot_types_NoClassException$vmethods;
typedef const struct _jc_polyglot_types_NoClassException$vtable	_jc_polyglot_types_NoClassException$vtable;
typedef const struct _jc_polyglot_types_NoClassException$vtype	_jc_polyglot_types_NoClassException$vtype;

// Constructors
extern void _jc_polyglot_types_NoClassException$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_types_NoClassException$object *, struct _jc_java_lang_String$object *);
extern void _jc_polyglot_types_NoClassException$method$_init$78f9c57fc1730f4d(_jc_env *, struct _jc_polyglot_types_NoClassException$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_polyglot_types_NoClassException$method$_init$554f76f5bea40c52(_jc_env *, struct _jc_polyglot_types_NoClassException$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_util_Position$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_types_NoClassException$method$getClassName$333433582f896913(_jc_env *, struct _jc_polyglot_types_NoClassException$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_NoClassException$method_info$getClassName$333433582f896913;

// Virtual methods structure
struct _jc_polyglot_types_NoClassException$vmethods {
	struct _jc_java_lang_String$object	*(*getClassName$333433582f896913)(_jc_env *, struct _jc_polyglot_types_NoClassException$object *);
};

// Vtable
struct _jc_polyglot_types_NoClassException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_polyglot_types_SemanticException$vmethods	polyglot_types_SemanticException;
	_jc_polyglot_types_NoClassException$vmethods	polyglot_types_NoClassException;
};

// Vtype
struct _jc_polyglot_types_NoClassException$vtype {
	_jc_type			type;
	_jc_polyglot_types_NoClassException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_NoClassException$sub_refs {
	struct _jc_java_lang_String$object	*className;
};

// Reference instance fields (object)
struct _jc_polyglot_types_NoClassException$refs {
    _jc_polyglot_types_NoClassException$sub_refs	polyglot_types_NoClassException;
    _jc_polyglot_types_SemanticException$sub_refs	polyglot_types_SemanticException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_NoClassException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_NoClassException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_polyglot_types_SemanticException$sub_nonrefs	polyglot_types_SemanticException;
    _jc_polyglot_types_NoClassException$sub_nonrefs	polyglot_types_NoClassException;
};

// Object instance structure
struct _jc_polyglot_types_NoClassException$object {
	_jc_polyglot_types_NoClassException$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_NoClassException$vtype	*vtype;
	_jc_polyglot_types_NoClassException$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_NoClassException$vtype _jc_polyglot_types_NoClassException$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_NoClassException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_NoClassException$class_object;

#endif	/* _JC_polyglot_types_NoClassException_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/NoClassException.h <==
// public class polyglot.types.NoClassException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 7e014a610596faf9 polyglot_types_NoClassException
// @dep_class 45f755f5298b5b39 polyglot_types_SemanticException

// header file dependencies
// @dep_header polyglot_types_SemanticException

#include "polyglot/types/SemanticException.h"

#ifndef _JC_polyglot_types_NoClassException_H_
#define _JC_polyglot_types_NoClassException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_ClassType$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_types_NoClassException$sub_refs	_jc_polyglot_types_NoClassException$sub_refs;
typedef struct _jc_polyglot_types_NoClassException$sub_nonrefs	_jc_polyglot_types_NoClassException$sub_nonrefs;
typedef struct _jc_polyglot_types_NoClassException$refs	_jc_polyglot_types_NoClassException$refs;
typedef struct _jc_polyglot_types_NoClassException$nonrefs	_jc_polyglot_types_NoClassException$nonrefs;
typedef struct _jc_polyglot_types_NoClassException$object	_jc_polyglot_types_NoClassException$object;

typedef const struct _jc_polyglot_types_NoClassException$vmethods	_jc_polyglot_types_NoClassException$vmethods;
typedef const struct _jc_polyglot_types_NoClassException$vtable	_jc_polyglot_types_NoClassException$vtable;
typedef const struct _jc_polyglot_types_NoClassException$vtype	_jc_polyglot_types_NoClassException$vtype;

// Constructors
extern void _jc_polyglot_types_NoClassException$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_types_NoClassException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_types_NoClassException$method$_init$78f9c57fc1730f4d(_jc_env *, struct _jc_polyglot_types_NoClassException$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_types_NoClassException$method$_init$554f76f5bea40c52(_jc_env *, struct _jc_polyglot_types_NoClassException$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_types_NoClassException$method$getClassName$333433582f896913(_jc_env *, struct _jc_polyglot_types_NoClassException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_NoClassException$method_info$getClassName$333433582f896913;

// Virtual methods structure
struct _jc_polyglot_types_NoClassException$vmethods {
	struct _jc_java_lang_String$object	*(*getClassName$333433582f896913)(_jc_env *, struct _jc_polyglot_types_NoClassException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_types_NoClassException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_polyglot_types_SemanticException$vmethods	polyglot_types_SemanticException;
	_jc_polyglot_types_NoClassException$vmethods	polyglot_types_NoClassException;
};

// Vtype
struct _jc_polyglot_types_NoClassException$vtype {
	_jc_type			type;
	_jc_polyglot_types_NoClassException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_NoClassException$sub_refs {
	struct _jc_java_lang_String$object	*className;
};

// Reference instance fields (object)
struct _jc_polyglot_types_NoClassException$refs {
    _jc_polyglot_types_NoClassException$sub_refs	polyglot_types_NoClassException;
    _jc_polyglot_types_SemanticException$sub_refs	polyglot_types_SemanticException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_NoClassException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_NoClassException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_polyglot_types_SemanticException$sub_nonrefs	polyglot_types_SemanticException;
    _jc_polyglot_types_NoClassException$sub_nonrefs	polyglot_types_NoClassException;
};

// Object instance structure
struct _jc_polyglot_types_NoClassException$object {
	_jc_polyglot_types_NoClassException$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_NoClassException$vtype	*vtype;
	_jc_polyglot_types_NoClassException$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_NoClassException$vtype _jc_polyglot_types_NoClassException$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_NoClassException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_NoClassException$class_object;

#endif	/* _JC_polyglot_types_NoClassException_H_ */
